=================
Bodhi Server APIs
=================

fedmsg API
==========

The fedmsgs bodhi sends
`are documented by the Fedora fedmsg project <https://fedora-fedmsg.readthedocs.io/en/latest/topics.html#bodhi>`_.


REST API
========

This section of the documentation describes Bodhi's REST API. You can read about the various
sections of the API by following the links below:


.. toctree::
   :maxdepth: 2

   admin
   builds
   comments
   composes
   csrf
   markdown
   overrides
   packages
   releases
   stacks
   updates
   users
